@@ -17,7 +17,7 @@ class Pingu(Actor):
 
     def __init__(self, x=0, y=0):
         Actor.__init__(self, x=x, y=y)
-        self.animacion = pilas.imagenes.Grilla("pingu.png", 10)
+        self.animacion = pilas.imagenes.cargar_grilla("pingu.png", 10)
         self.definir_cuadro(4)
         self.hacer(Esperando())
         self.radio_de_colision = 30
@@ -76,17 +76,18 @@ class Saltando(Comportamiento):
 
     def __init__(self):
         self.dy = 10
-    
+        
     def iniciar(self, receptor):
         self.receptor = receptor
         self.receptor.definir_cuadro(0)
-
+        self.origen = self.receptor.y
+        
     def actualizar(self):
         self.receptor.y += self.dy
         self.dy -= 0.3
 
-        if self.receptor.y < 0:
-            self.receptor.y = 0
+        if self.receptor.y < self.origen:
+            self.receptor.y = self.origen
             self.receptor.hacer(Esperando())
 
         if pilas.mundo.control.izquierda:
