@@ -2,12 +2,13 @@ import pygame
 
 class FPS:
 
-    def __init__(self, fps):
+    def __init__(self, fps, usar_modo_economico):
         self.antes = self.ahora = pygame.time.get_ticks()
         self.frecuencia = 1000.0 / fps
         self.t_fps = self.ahora
         self.rendimiento = 0
         self.cuadros_por_segundo = "??"
+        self.usar_modo_economico = usar_modo_economico
 
     def actualizar(self):
         retorno = 0
@@ -26,9 +27,17 @@ class FPS:
                 self.t_fps += 1000.0
                 self.rendimiento = 0
         else:
-            pygame.time.delay(int(self.frecuencia - dt))
+            if self.usar_modo_economico:
+                pygame.time.wait(int(self.frecuencia - dt))
+            else:
+                pygame.time.delay(int(self.frecuencia - dt))
+
             returno = 1
 
 
         self.rendimiento += 1
         return retorno
+
+
+    def obtener_cuadros_por_segundo(self):
+        return self.cuadros_por_segundo
\ No newline at end of file
